==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
var PolarLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesDescriptionMetadata, _super);
    function PolarLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarLineSeriesDescriptionMetadata.b = function (a) {
        if (PolarLineSeriesDescriptionMetadata.a == null) {
            PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
        }
        if (a.k(PolarLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ab(PolarLineSeriesDescriptionMetadata.a);
    };
    PolarLineSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    PolarLineSeriesDescriptionMetadata.d = function (a) {
        PolarLineSeriesDescriptionMetadata.b(a);
        a.ad("PolarLineSeries", function () { return new PolarLineSeriesDescription(); });
        a.ac("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
    };
    PolarLineSeriesDescriptionMetadata.$t = markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
}(Base));
export { PolarLineSeriesDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/PolarLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarLineSeriesDescription } from "./PolarLineSeriesDescription";
/**
 * @hidden
 */
var PolarLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesDescriptionMetadata, _super);
    function PolarLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarLineSeriesDescriptionMetadata.b = function (a) {
        if (PolarLineSeriesDescriptionMetadata.a == null) {
            PolarLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarLineSeriesDescriptionMetadata.c(PolarLineSeriesDescriptionMetadata.a);
        }
        if (a.k(PolarLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.ac(PolarLineSeriesDescriptionMetadata.a);
    };
    PolarLineSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    PolarLineSeriesDescriptionMetadata.d = function (a) {
        PolarLineSeriesDescriptionMetadata.b(a);
        a.ae("PolarLineSeries", function () { return new PolarLineSeriesDescription(); });
        a.ad("PolarLineSeries", PolarLineSeriesDescriptionMetadata.a);
    };
    PolarLineSeriesDescriptionMetadata.$t = markType(PolarLineSeriesDescriptionMetadata, 'PolarLineSeriesDescriptionMetadata');
    PolarLineSeriesDescriptionMetadata.a = null;
    return PolarLineSeriesDescriptionMetadata;
}(Base));
export { PolarLineSeriesDescriptionMetadata };
